Use this macro in place of tracing::instrument to prevent spamming our tracing table.
We set a default level of INFO while always setting ERROR if the function returns Result::Err giving us
consistent and high quality structured logs. Because this wraps around tracing::instrument, all parameters
mentioned in https://fburl.com/9jlkb5q4 should be valid. For functions that don’t return a Result type, use
instrument_infallible
Use this macro in place of tracing::instrument to prevent spamming our tracing table.
Because this wraps around tracing::instrument, all parameters mentioned in
https://fburl.com/9jlkb5q4 should be valid.
Derive a custom handler trait for given an enum containing tuple
structs. The handler trait defines a method corresponding
to each of the enum’s variants, and a handle function
that dispatches messages to the correct method. The macro
supports two messaging patterns: “call” and “oneway”. A call is a
request-response message; a [hyperactor::mailbox::OncePortRef] or
[hyperactor::mailbox::OncePortHandle] in the last position is used
to send the return value.
Derive the [hyperactor::data::Named] trait for a struct with the
provided type URI. The name of the type is its fully-qualified Rust
path. The name may be overridden by providing a string value for the
name attribute.